@@ -12,14 +12,27 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-pub mod fp;
-pub mod fp4;
-pub mod ntt;
-pub mod poly;
-pub mod rou;
-pub mod sha;
-pub mod sha_rng;
+#![no_std]
 
-pub fn to_po2(x: usize) -> usize {
-    (31 - (x as u32).leading_zeros()) as usize
+#[cfg(feature = "cxx")]
+#[cxx::bridge]
+mod ffi {}
+
+cfg_if::cfg_if! {
+    if #[cfg(feature = "pure")] {
+        extern crate alloc;
+
+        pub mod fp;
+        pub mod fp4;
+        pub mod ntt;
+        pub mod poly;
+        pub mod rou;
+        pub mod sha;
+        pub mod sha_cpu;
+        pub mod sha_rng;
+
+        pub fn to_po2(x: usize) -> usize {
+            (31 - (x as u32).leading_zeros()) as usize
+        }
+    }
 }
